@@ -53,11 +53,6 @@ use Carp;
 	$mixer_out_format 				$config->{mixer_out_format}
 	$sample_rate					$config->{sample_rate}
 	$ecasound_tcp_port 				$config->{engine_tcp_port}
-	$ecasound_globals_general 		$config->{engine_globals}->{common}
-	$ecasound_globals_realtime 		$config->{engine_globals}->{realtime}
-	$ecasound_globals_nonrealtime 	$config->{engine_globals}->{nonrealtime}
-	$ecasound_buffersize_realtime   $config->{engine_buffersize}->{realtime}->{default}
-	$ecasound_buffersize_nonrealtime $config->{engine_buffersize}->{nonrealtime}->{default}
 	$ecasound_globals				$config->{engine_globals}
 	$ecasound_buffersize 			$config->{engine_buffersize} 
 	$realtime_profile 				$config->{realtime_profile}
@@ -263,10 +258,6 @@ $mode
 $file
 $graph
 $setup
-
-
-
-
 $config
 $jack
 $fx
