@@ -1,7 +1,7 @@
 # --------------------- Command Grammar ----------------------
 
 package Audio::Nama;
-use Audio::Nama::Effects qw(:all);
+use Audio::Nama::Effect  qw(:all);
 use Modern::Perl;
 
 sub setup_grammar {
@@ -42,6 +42,7 @@ sub setup_grammar {
 
 }
 sub process_line {
+	state $total_effects_count;
 	logsub("&process_line");
 	no warnings 'uninitialized';
 	my ($user_input) = @_;
@@ -85,6 +86,11 @@ sub process_line {
 			(ref $this_track and ! $tn{$this_track->name});
 		setup_hotkeys() if $config->{hotkeys_always};
 	}
+	if (! engine_running() ){
+		my $result = check_fx_consistency();
+		logpkg(__FILE__,__LINE__,'logcluck',"Inconsistency found in effects data",
+			Dumper ($result)) if $result->{is_error};
+	}
 	revise_prompt( $mode->{midish_terminal} and "Midish > " );
 	my $output = delete $text->{output_buffer};
 }
@@ -96,55 +102,45 @@ sub context {
 	$context
 }
 sub process_command {
-	state $total_effects_count;
 	my $input = shift;
 	my $input_was = $input;
 
 	# parse repeatedly until all input is consumed
+	# return true on complete success
+	# return false if any part of command fails
 	
-	my $was_error;
+	my $was_error = 0;
 	
 	try {
-	while (do { no warnings 'uninitialized'; $input =~ /\S/ }) { 
-		logpkg(__FILE__,__LINE__,'debug',"input: $input");
-		$text->{parser}->meta(\$input) or do
-		{
-			throw("bad command: $input_was\n"); 
-			$was_error++;
-			system($config->{beep_command}) if $config->{beep_command};
-			last;
-		};
-			
-	}
+		while (do { no warnings 'uninitialized'; $input =~ /\S/ }) { 
+			logpkg(__FILE__,__LINE__,'debug',"input: $input");
+			$text->{parser}->meta(\$input) or do
+			{
+				throw("bad command: $input_was\n"); 
+				$was_error++;
+				system($config->{beep_command}) if $config->{beep_command};
+				last;
+			};
+		}
 	}
 	catch { $was_error++; warn "caught error: $_" };
 		
 	$ui->refresh; # in case we have a graphic environment
 	set_current_bus();
+
 	# select chain operator if appropriate
-	no warnings 'uninitialized';
-	my $FX = fxn($this_track->op);
-	if ($FX and $this_track->n eq $FX->chain){
-		eval_iam("c-select ".$this_track->n);
-		eval_iam("cop-select ".  $FX->ecasound_effect_index);
+	# and there is a current track
+
+
+	if ($this_track){
+		my $FX = fxn($this_track->op);
+		if ($FX and $this_track->n eq $FX->chain){
+			eval_iam("c-select ".$this_track->n);
+			eval_iam("cop-select ".  $FX->ecasound_effect_index);
+		}
 	}
 
-	my $result = check_fx_consistency();
-	logpkg(__FILE__,__LINE__,'logcluck',"Inconsistency found in effects data",
-		Dumper ($result)) if $result->{is_error};
-
-	my $current_count= 0;
-	map{ $current_count++ } keys %{$fx->{applied}};
-	if ($current_count < $total_effects_count){
-		pager("Total effects count: $current_count, change: ",
-			$current_count - $total_effects_count);
-		$total_effects_count = $current_count;
-	}
-	# return true on complete success
-	# return false on any part of command failure
-	
-	return ! $was_error
-		
+	! $was_error
 }
 sub do_user_command {
 	my($cmd, @args) = @_;
@@ -199,7 +195,7 @@ sub user_set_current_track {
 		
 }
 
-### allow commands to abbreviate Audio::Nama::Class as Audio::Nama::Class
+### allow commands to abbreviate Audio::Nama::Class as ::Class # SKIP_PREPROC
 
 { my @namespace_abbreviations = qw(
 	Assign 
@@ -213,6 +209,7 @@ sub user_set_current_track {
 	Fade                                                      
 	Edit
 	Text
+	Effect
 	EffectChain
 	ChainSetup
 );
@@ -263,15 +260,15 @@ sub show_effects {
 }
 sub list_effects {
 	Audio::Nama::sync_effect_parameters();
-	join " ", "Effects on", $this_track->name.':', map{ list_effect($_) } @{ $this_track->ops };
+	join "", "Effects on ", $this_track->name,":\n", map{ list_effect($_) } @{ $this_track->ops };
 }
 
 sub list_effect {
 	my $op_id = shift;
 	my $FX = fxn($op_id);
-	my $name = $FX->name;
-	$name .= q(, bypassed) if $FX->bypassed;
-	($op_id eq $this_track->op ? '*' : '') . "$op_id ($name)";
+	my $line = $FX->nameline;
+	$line .= q(, bypassed) if $FX->bypassed;
+	($op_id eq $this_track->op ? ' *' : '  ') . $line;
 }
 
 sub show_effect {
@@ -290,8 +287,8 @@ sub show_effect {
 	map
 	{ 	push @lines, parameter_info_padded($op_id, $_) 
 	 	
-	} (scalar @pnames .. (scalar @{$fx->{params}->{$op_id}} - 1)  )
-		if scalar @{$fx->{params}->{$op_id}} - scalar @pnames - 1; 
+	} (scalar @pnames .. (scalar @{$FX->params} - 1)  )
+		if scalar @{$FX->params} - scalar @pnames - 1; 
 	@lines
 }
 sub extended_name {
@@ -412,8 +409,8 @@ sub show_tracks_section {
             $_->rec_status_display,
 			placeholder($_->source_status),
 			placeholder($_->destination),
-			placeholder($fx->{params}->{$_->vol}->[0]),
-			placeholder($fx->{params}->{$_->pan}->[0]),
+			placeholder($_->vol_level),
+			placeholder($_->pan_level),
         } @tracks;
         
 	my $output = $^A;
@@ -552,10 +549,10 @@ sub destroy_current_wav {
 
 sub pan_check {
 	my ($track, $new_position) = @_;
-	my $current = $fx->{params}->{ $track->pan }->[0];
+	my $current = $track->pan_o->params->[0];
 	$track->set(old_pan_level => $current)
 		unless defined $track->old_pan_level;
-	effect_update_copp_set(
+	update_effect(
 		$track->pan,	# id
 		0, 					# parameter
 		$new_position,		# value
@@ -578,7 +575,7 @@ sub unity {
 	if ($save_level){
 		$track->set(old_vol_level => fxn($track->vol)->params->[0]);
 	}
-	effect_update_copp_set( 
+	update_effect( 
 		$track->vol, 
 		0, 
 		$config->{unity_level}->{fxn($track->vol)->type}
@@ -588,7 +585,7 @@ sub vol_back {
 	my $track = shift;
 	my $old = $track->old_vol_level;
 	if (defined $old){
-		effect_update_copp_set(
+		update_effect(
 			$track->vol,	# id
 			0, 					# parameter
 			$old,				# value
@@ -601,7 +598,7 @@ sub pan_back {
 	my $track = shift;
 	my $old = $track->old_pan_level;
 	if (defined $old){
-		effect_update_copp_set(
+		update_effect(
 			$track->pan,	# id
 			0, 					# parameter
 			$old,				# value
