@@ -632,7 +632,7 @@ sub track_gui {
 		my %p = ( 	parent => \$gui->{track_frame},
 				chain  => $n,
 				type => 'ea',
-				effect_id => $vol_id,
+				id => $vol_id,
 				p_num		=> $p_num,
 				length => 300, 
 				);
@@ -646,8 +646,9 @@ sub track_gui {
 
 		$mute = $gui->{track_frame}->Button(
 			-command => sub { 
-				if ($fx->{params}->{$vol_id}->[0] != $config->{mute_level}->{$fx->{applied}->{$vol_id}->{type}} and
-					$fx->{params}->{$vol_id}->[0] != $config->{fade_out_level}->{$fx->{applied}->{$vol_id}->{type}}
+				my $FX = fxn($vol_id);
+				if (	$FX->params->[0] != $config->{mute_level}->{$FX->type} 
+					and $FX->params->[0] != $config->{fade_out_level}->{$FX->type} 
 				) {  # non-zero volume
 					$ti{$n}->mute;
 					$mute->configure(-background => $gui->{_nama_palette}->{Mute});
@@ -663,10 +664,11 @@ sub track_gui {
 
 		$unity = $gui->{track_frame}->Button(
 				-command => sub { 
-					Audio::Nama::effect_update_copp_set(
+					my $FX = fxn($vol_id);
+					Audio::Nama::update_effect(
 						$vol_id, 
 						0, 
-						$config->{unity_level}->{$fx->{applied}->{$vol_id}->{type}});
+						$config->{unity_level}->{$FX->type});
 				}
 		  );
 	} else {
@@ -688,7 +690,7 @@ sub track_gui {
 		my %q = ( 	parent => \$gui->{track_frame},
 				chain  => $n,
 				type => 'epp',
-				effect_id => $pan_id,
+				id => $pan_id,
 				p_num		=> $p_num,
 				);
 		# logpkg(__FILE__,__LINE__,'debug',sub{ my %q = %p; delete $q{parent}; print "x=============\n%p\n",json_out(\%q) });
@@ -698,7 +700,7 @@ sub track_gui {
 
 		$center = $gui->{track_frame}->Button(
 			-command => sub { 
-				Audio::Nama::effect_update_copp_set($pan_id, 0, 50);
+				Audio::Nama::update_effect($pan_id, 0, 50);
 			}
 		  );
 	} else { 
@@ -840,26 +842,27 @@ sub add_effect_gui {
 		logsub("&add_effect_gui");
 		my $ui = shift;
 		my %p 			= %{shift()};
-		my ($n,$code,$id,$parent_id,$parameter) =
-			@p{qw(chain type effect_id parent_id parameter)};
+		my ($n,$code,$id,$parent,$parameter) =
+			@p{qw(chain type id parent parameter)};
 		my $i = $fx_cache->{full_label_to_index}->{$code};
+		my $FX = fxn($id);
 
 		logpkg(__FILE__,__LINE__,'debug', sub{json_out(\%p)});
 
-		logpkg(__FILE__,__LINE__,'debug', "effect_id: $id, parent_id: $parent_id");
+		logpkg(__FILE__,__LINE__,'debug', "id: $id, parent: $parent");
 		# $id is determined by effect_init, which will return the
-		# existing effect_id if supplied
+		# existing id if supplied
 
 		# check display format, may be 'scale' 'field' or 'hidden'
 		
-		my $display_type = $fx->{applied}->{$id}->{display}; # individual setting
+		my $display_type = $FX->display; # individual setting
 		defined $display_type or $display_type = $fx_cache->{registry}->[$i]->{display}; # template
 		logpkg(__FILE__,__LINE__,'debug', "display type: $display_type");
 
 		return if $display_type eq q(hidden);
 
 		my $frame ;
-		if ( ! $parent_id ){ # independent effect
+		if ( ! $parent ){ # independent effect
 			$frame = $gui->{tracks}->{$n}->{parents}->Frame->pack(
 				-side => 'left', 
 				-anchor => 'nw',)
@@ -874,8 +877,9 @@ sub add_effect_gui {
 
 		# here add menu items for Add Controller, and Remove
 
-		my $parentage = $fx_cache->{registry}->[ $fx_cache->{full_label_to_index}->{ $fx->{applied}->{$parent_id}->{type}} ]
-			->{name};
+		my $parentage = $fx_cache->{registry}->[
+			$fx_cache->{full_label_to_index}->{$FX->type} 
+		]->{name};
 		$parentage and $parentage .=  " - ";
 		logpkg(__FILE__,__LINE__,'debug', "parentage: $parentage");
 		my $eff = $frame->Menubutton(
@@ -897,11 +901,11 @@ sub add_effect_gui {
 		for my $j ($fx_cache->{split}->{ctrl}{a}..$fx_cache->{split}->{ctrl}{z}) {   
 			push @items, 				
 				[ 'command' => $fx_cache->{registry}->[$j]->{name},
-					-command => sub { add_effect ({
-							parent_id => $id,
-							chain => $n,
-							values => [ $p  + 1 ],
-							type => $fx_cache->{registry}->[$j]->{code} } )  }
+					-command => sub { add_effect({
+							parent 	=> $id,
+							chain 	=> $n,
+							params 	=> [ $p  + 1 ],
+							type 	=> $fx_cache->{registry}->[$j]->{code} })  }
 				];
 
 		}
@@ -914,7 +918,7 @@ sub add_effect_gui {
 				$fx_cache->{registry}->[$i]->{params}->[$p]->{name});
 			my $v =  # for argument vector 
 			{	parent => \$frame,
-				effect_id => $id, 
+				id => $id, 
 				p_num  => $p,
 			};
 			push @sliders,make_scale($v);
@@ -956,7 +960,8 @@ sub remove_effect_gui {
 	my $ui = shift;
 	logsub("&remove_effect_gui");
 	my $id = shift;
-	my $n = $fx->{applied}->{$id}->{chain};
+	my $FX = fxn($id);
+	my $n = $FX->chain;
 	logpkg(__FILE__,__LINE__,'debug', "id: $id, chain: $n");
 
 	logpkg(__FILE__,__LINE__,'debug', "i have widgets for these ids: ", join " ",keys %{$gui->{fx}});
@@ -1005,13 +1010,14 @@ sub make_scale {
 	my $ref = shift;
 	my %p = %{$ref};
 # 	%p contains following:
-# 	effect_id   => operator id, to access dynamic effect params in %{$fx->{params}}
+# 	id   => operator id
 # 	parent => parent widget, i.e. the frame
 # 	p_num      => parameter number, starting at 0
 # 	length       => length widget # optional 
-	my $id = $p{effect_id};
-	my $n = $fx->{applied}->{$id}->{chain};
-	my $code = $fx->{applied}->{$id}->{type};
+	my $id = $p{id};
+	my $FX = fxn($id);
+	my $n = $FX->chain;
+	my $code = $FX->type;
 	my $p  = $p{p_num};
 	my $i  = $fx_cache->{full_label_to_index}->{$code};
 
@@ -1021,7 +1027,7 @@ sub make_scale {
 	# check display format, may be text-field or hidden,
 
 	logpkg(__FILE__,__LINE__,'debug',"i: $i code: $fx_cache->{registry}->[$i]->{code} display: $fx_cache->{registry}->[$i]->{display}");
-	my $display_type = $fx->{applied}->{$id}->{display};
+	my $display_type = $FX->display;
 	defined $display_type or $display_type = $fx_cache->{registry}->[$i]->{display};
 	logpkg(__FILE__,__LINE__,'debug', "display type: $display_type");
 	return if $display_type eq q(hidden);
@@ -1047,15 +1053,15 @@ sub make_scale {
 		my $log_display;
 		
 		my $controller = $frame->Scale(
-			-variable => \$fx->{params}->{$id}->[$p],
+			-variable => \$FX->{params}->[$p],
 			-orient => 'horizontal',
 			-from   =>  $fx_cache->{registry}->[$i]->{params}->[$p]->{begin},
 			-to     =>  $fx_cache->{registry}->[$i]->{params}->[$p]->{end},
 			-resolution => resolution($i, $p),
 		  -width => 12,
 		  -length => $p{length} ? $p{length} : 100,
-		  -command => sub { Audio::Nama::effect_update($id, $p, $fx->{params}->{$id}->[$p]) },
-			-state => fxn($id)->is_read_only($p) ? 'disabled' : 'normal',
+		  -command => sub { Audio::Nama::_update_effect($id, $p, $FX->params->[$p]) },
+			-state => $FX->is_read_only($p) ? 'disabled' : 'normal',
 		  );
 
 		# auxiliary field for logarithmic display
@@ -1067,15 +1073,15 @@ sub make_scale {
 				-width => 5,
 				);
 			$controller->configure(
-				-variable => \$fx->{params_log}->{$id}->[$p],
+				-variable => \$FX->{params_log}->[$p],
 		  		-command => sub { 
-					$fx->{params}->{$id}->[$p] = exp $fx->{params_log}->{$id}->[$p];
-					Audio::Nama::effect_update($id, $p, $fx->{params}->{$id}->[$p]);
+					$FX->params->[$p] = exp $FX->params_log->[$p];
+					Audio::Nama::_update_effect($id, $p, $FX->params->[$p]);
 					$log_display->configure(
 						-text => 
 						$fx_cache->{registry}->[$i]->{params}->[$p]->{name} =~ /hz|frequency/i
-							? int $fx->{params}->{$id}->[$p]
-							: dn($fx->{params}->{$id}->[$p], 1)
+							? int $FX->params->[$p]
+							: dn($FX->params->[$p], 1)
 						);
 					}
 				);
@@ -1092,9 +1098,9 @@ sub make_scale {
 	 	# then return field type controller widget
 
 		return ${ $p{parent} }->Entry(
-			-textvariable =>\$fx->{params}->{$id}->[$p],
+			-textvariable =>\$FX->params->[$p],
 			-width => 6,
-	#		-command => sub { Audio::Nama::effect_update($id, $p, $fx->{params}->{$id}->[$p]) },
+	#		-command => sub { Audio::Nama::_update_effect($id, $p, $FX->params->[$p]) },
 			# doesn't work with Entry widget
 			);	
 
